// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-

/* The name of this package (not localized) */
const PACKAGE_NAME = 'gnome-shell';
/* The version of this package */
const PACKAGE_VERSION = '3.10.4';
/* 1 if gnome-bluetooth is available, 0 otherwise */
const HAVE_BLUETOOTH = 0;
/* 1 if networkmanager is available, 0 otherwise */
const HAVE_NETWORKMANAGER = 0;
/* gettext package */
const GETTEXT_PACKAGE = 'gnome-shell';
/* locale dir */
const LOCALEDIR = '/usr/local/share/locale';
/* other standard directories */
const LIBEXECDIR = '/usr/local/libexec';
const SYSCONFDIR = '/etc';
